@@ -179,7 +179,7 @@ class Current(object):
         except Exception:
             olddata = {}
         if self._currentdict != olddata:
-            log.debug("writing current %s", self.path)
+            log.info("writing current %s", self.path)
             oldumask = os.umask(7 * 8 + 7)
             try:
                 self.path.write(
